/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean.context;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import edu.uiuc.ncsa.cet.bean.CETBean;
import edu.uiuc.ncsa.cet.bean.PersonBean;

public class ContextBean extends CETBean
{
    /** Used for serialization of object */
    private static final long   serialVersionUID = 1L;

    /** Title of the context */
    private String              title            = "";                           //$NON-NLS-1$

    /** Description of the context */
    private String              description      = "";                           //$NON-NLS-1$

    /** Date the context is created */
    private Date                date             = new Date();

    /** creator of the context */
    private PersonBean          creator          = null;

    /** type of context */
    private String              type             = null;

    /** map of properties that define the associated context */
    private Map<String, String> properties       = new HashMap<String, String>();

    /** list of child contexts */
    private List<ContextBean>   children         = new ArrayList<ContextBean>();

    /**
     * Create a new instance of the context. Real context will need to be loaded
     * using either PeerFacade or the ContextUtil class.
     */
    public ContextBean()
    {
    }

    // TODO: Hacks
    @Override
    public String getLabel()
    {
        return getTitle();
    }

    /**
     * Return the title of the context.
     * 
     * @return title of the context
     */
    public String getTitle()
    {
        return title;
    }

    /**
     * Sets the title of the context
     * 
     * @param title
     *            sets the title of the context.
     * 
     */
    public void setTitle( String title )
    {
        this.title = title;
    }

    /**
     * Return the description of the context.
     * 
     * @return description of the context
     */
    public String getDescription()
    {
        return description;
    }

    /**
     * Sets the description of the context
     * 
     * @param description
     *            sets the description of the context.
     * 
     */
    public void setDescription( String description )
    {
        this.description = description;
    }

    /**
     * Return the date when the context was created.
     * 
     * @return date the context was created.
     */
    public Date getDate()
    {
        return date;
    }

    /**
     * Sets the date when the context was created.
     * 
     * @param date
     *            sets the date when the context was created.
     * 
     */
    public void setDate( Date date )
    {
        this.date = date;
    }

    /**
     * Return the PersonBean that is the creator of the context
     * 
     * @return PersonBean that represents the creator
     */
    public PersonBean getCreator()
    {
        return creator;
    }

    /**
     * Sets the PersonBean that represents the creator of the context.
     * 
     * @param creator
     *            sets the PersonBean that represents the creator of the
     *            context.
     * 
     */
    public void setCreator( PersonBean creator )
    {
        this.creator = creator;
    }

    /**
     * Properties that define the context definition. The primary purpose of
     * this list is for editing the context.
     * 
     * @return map of properties defining the context.
     */
    public Map<String, String> getProperties()
    {
        return properties;
    }

    /**
     * Properties that define the context definition. The primary purpose of
     * this list is for editing the context.
     * 
     * @param map
     *            of properties defining the context.
     */
    public void setProperties( Map<String, String> properties )
    {
        this.properties = properties;
    }

    /**
     * Add a property to the list of properties. The primary purpose of this
     * list is for editing the context.
     * 
     * @param key
     *            key of the property.
     * @param val
     *            the value of the property.
     */
    public void addProperty( String key, String val )
    {
        this.properties.put( key, val );
    }

    /**
     * Returns the request property from the list of properties. The primary
     * purpose of this list is for editing the context.
     * 
     * @param key
     *            key of the property.
     * @return the value of the property.
     */
    public String getProperty( String key )
    {
        return this.properties.get( key );
    }

    /**
     * Returns the request property from the list of properties. The primary
     * purpose of this list is for editing the context. Properties can be stored
     * as a variable in which case the real value is stored in the parameters
     * map. Variables are indicated by $&lt;variablename&gt;. Parameters will
     * contain the mapping from $&lt;variablename&gt; to the real value.
     * 
     * @param key
     *            key of the property.
     * @param parameters
     *            values for variables
     * @return the value of the property.
     */
    public String getProperty( String key, Map<String, String> parameters )
    {
        String result = this.properties.get( key );
        if ( (result != null) && result.startsWith( "$" ) ) {
            if ( parameters == null ) {
                return null;
            }
            return parameters.get( result );
        }
        return result;
    }

    /**
     * Deletes the request property from the list of properties. The primary
     * purpose of this list is for editing the context.
     * 
     * @param key
     *            key of the property.
     */
    public void removeProperty( String key )
    {
        this.properties.remove( key );
    }

    /**
     * REturns the request property from the list of properties. The primary
     * purpose of this list is for editing the context.
     * 
     * @param key
     *            key of the property.
     * @param dflt
     *            the default value if the value stored is null.
     * @return the value of the property.
     */
    public String getProperty( String key, String dflt )
    {
        String result = this.properties.get( key );
        if ( result == null ) {
            return dflt;
        }
        return result;
    }

    /**
     * Return the type of the context, this is mapped to the context creator.
     * 
     * @return the context type
     */
    public String getType()
    {
        return type;
    }

    /**
     * Sets the type of the context, this is mapped to the context creator.
     * 
     * @param type
     *            the type of the context to set.
     */
    public void setType( String type )
    {
        this.type = type;
    }

    /**
     * Returns the list of child contexts, this is only useful for those
     * contexts that support child contexts (i.e. Union and Routing)
     * 
     * @return the child contexts.
     */
    public List<ContextBean> getChildren()
    {
        return children;
    }

    /**
     * Sets the list of child contexts, this is only useful for those contexts
     * that support child contexts (i.e. Union and Routing)
     * 
     * @param children
     *            the children to set
     */
    public void setChildren( List<ContextBean> children )
    {
        this.children = children;
    }

}
